EnterResp

Enum EnterResp 

pub enum EnterResp {
    AccountDoesNotExist,
    AttributeBanned(Attr),
    Banned,
    AttributeAlreadyTaken {
        attr: Attr,
        bans_other_user: bool,
    },
    NoBannableAttribute,
    RetryWithNewIdentifyingAttr,
    RetryWithNewAuthToken,
    RetryWithNewAddAttr {
        index: usize,
    },
    Entered {
        new_account: bool,
        auth_token_package: Result<AuthTokenPackage, AuthTokenDeniedReason>,
        attr_status: Vec<(Attr, AttrAddStatus)>,
    },
}
Returned by EnterEP.

Variants



AccountDoesNotExist

Happens only in EnterMode::Login



AttributeBanned(Attr)

This attribute is banned and therefore cannot be used.



Banned

Cannot login, because this account is banned.



AttributeAlreadyTaken

The given identifying attribute (in EnterReq::add_attrs or EnterReq::identifying_attr) is already tied to another account.

If EnterReq::register_only_with_unique_attrs is set, this variant will also be returned if a registration is attempted, but one of the supplied attributes already bans another user.

May occasionally happen under the EnterMode::LoginOrRegister mode if the account was created by some parallel invocation of EnterEP at about the same time.

Fields

attr: Attr
bans_other_user: bool

Set if this attribute was taken in the sense that it already bans another user.



NoBannableAttribute

Cannot register an account with these attributes: no bannable attribute provided.



RetryWithNewIdentifyingAttr

Signature on identifying attribute is invalid or expired; please reobtain the identifying attribute and retry. If this fails even with a fresh attribute something is wrong with the server.



RetryWithNewAuthToken

An authtoken was passed via the Authorization header that is expired or otherwise invalid.
Obtain a new one and retry.



RetryWithNewAddAttr

Signature on EnterReq::add_attrs attribute is invalid or expired; please reobtain the attribute and retry. If this fails even with a fresh attribute something is wrong with the server.

Fields

index: usize

add_attrs[index] is the offending attribute



Entered

The given identifying attribute (now) grants access to a pubhubs account.

Fields

new_account: bool

Whether we created a new account

auth_token_package: Result<AuthTokenPackage, AuthTokenDeniedReason>

An access token identifying the user towards pubhubs central.

May not be provided, for example, when the user is banned, or if no bannable attribute is currently associated to the user’s account.

attr_status: Vec<(Attr, AttrAddStatus)>