pub enum GetObjectResp {
RetryWithNewHmac,
NotFound,
}Expand description
Returned by GetObjectEP when there’s a problem. When there’s no problem an octet
stream is returned instead.
Variants
RetryWithNewHmac
The hmac you sent is invalid, probably because it is outdated.
Please retry after obtaining the current hmac from StateEP.
NotFound
The hmac was correct, so the object you requested probably did exist at one point,
but it does not longer. Please reload the list of stored objects via StateEP.