pub struct UserState {
pub allow_login_by: HashSet<Id>,
pub could_be_banned_by: HashSet<Id>,
pub stored_objects: HashMap<Handle, UserObjectDetails>,
}Expand description
State of a user’s account at pubhubs as shown to the user.
Fields
allow_login_by: HashSet<Id>Attributes that may be used to log in as this user.
could_be_banned_by: HashSet<Id>Attributes that when banned ban this user.
stored_objects: HashMap<Handle, UserObjectDetails>Objects stored for this user