pub struct GetObjectEP {}Expand description
Retrieves a user object with the given hash from PubHubs central
Authorization happens not via an access token, but using the UserObjectDetails::hmac.
This allows HTTP caching without leaking the access token to the cache.